@@ -156,7 +156,6 @@ gnc_reconcile_view_tooltip_cb (GNCQueryView *qview, gint x, gint y,
                 GdkDeviceManager *device_manager;
 #endif
                 GdkDevice *pointer;
-                GdkScreen *screen;
                 GtkWindow *tip_win = NULL;
                 GdkWindow *parent_window;
                 GList *win_list, *node;
@@ -174,9 +173,7 @@ gnc_reconcile_view_tooltip_cb (GNCQueryView *qview, gint x, gint y,
 
                 gdk_window_get_origin (parent_window, &root_x, &root_y);
 
-                screen = gtk_widget_get_screen (GTK_WIDGET (qview));
-
-                /* Get a list of toplevel windows */
+                 /* Get a list of toplevel windows */
                 win_list = gtk_window_list_toplevels ();
 
                 /* Look for the gtk-tooltip window, we do this as gtk_widget_get_tooltip_window
@@ -195,6 +192,7 @@ gnc_reconcile_view_tooltip_cb (GNCQueryView *qview, gint x, gint y,
 #if GTK_CHECK_VERSION(3,22,0)
                     GdkMonitor *mon;
 #else
+                    GdkScreen *screen;
                     gint monitor_num;
 #endif
                     GdkRectangle monitor;
@@ -210,6 +208,7 @@ gnc_reconcile_view_tooltip_cb (GNCQueryView *qview, gint x, gint y,
                     mon = gdk_display_get_monitor_at_point (gdk_display_get_default(), x, y);
                     gdk_monitor_get_geometry (mon, &monitor);
 #else
+                    screen = gtk_widget_get_screen (GTK_WIDGET (qview));
                     monitor_num = gdk_screen_get_monitor_at_point (screen, x, y);
                     gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 #endif
@@ -233,6 +232,38 @@ gnc_reconcile_view_tooltip_cb (GNCQueryView *qview, gint x, gint y,
 }
 
 
+gint
+gnc_reconcile_view_get_column_width (GNCReconcileView *view, gint column)
+{
+    GNCQueryView      *qview = GNC_QUERY_VIEW (view);
+    GtkTreeViewColumn *col;
+
+    //allow for pointer model column at column 0
+    col = gtk_tree_view_get_column (GTK_TREE_VIEW (qview), (column - 1));
+    return  gtk_tree_view_column_get_width (col);
+}
+
+
+void
+gnc_reconcile_view_add_padding (GNCReconcileView *view, gint column, gint xpadding)
+{
+    GNCQueryView      *qview = GNC_QUERY_VIEW (view);
+    GtkTreeViewColumn *col;
+    GList             *renderers;
+    GtkCellRenderer   *cr0;
+    gint xpad, ypad;
+
+    //allow for pointer model column at column 0
+    col = gtk_tree_view_get_column (GTK_TREE_VIEW (qview), (column - 1));
+    renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (col));
+    cr0 = g_list_nth_data (renderers, 0);
+    g_list_free (renderers);
+
+    gtk_cell_renderer_get_padding (cr0, &xpad, &ypad);
+    gtk_cell_renderer_set_padding (cr0, xpadding, ypad);
+}
+
+
 /****************************************************************************\
  * gnc_reconcile_view_new                                                   *
  *   creates the account tree                                               *
@@ -309,8 +340,8 @@ gnc_reconcile_view_new (Account *account, GNCReconcileViewType type,
 
     /* Create the list store with 6 columns and add to treeview,
        column 0 will be a pointer to the entry */
-    liststore = gtk_list_store_new (6, G_TYPE_POINTER, G_TYPE_BOOLEAN,
-                G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING );
+    liststore = gtk_list_store_new (6, G_TYPE_POINTER, G_TYPE_STRING,
+                G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,  G_TYPE_BOOLEAN );
     gtk_tree_view_set_model (GTK_TREE_VIEW (view), GTK_TREE_MODEL (liststore));
     g_object_unref (liststore);
 
@@ -388,6 +419,15 @@ gnc_reconcile_view_init (GNCReconcileView *view)
     view->account = NULL;
     view->sibling = NULL;
 
+    param = gnc_search_param_simple_new();
+    gnc_search_param_set_param_fcn (param, QOF_TYPE_BOOLEAN,
+                                    gnc_reconcile_view_is_reconciled, view);
+    gnc_search_param_set_title ((GNCSearchParam *) param, C_("Column header for 'Reconciled'", "R"));
+    gnc_search_param_set_justify ((GNCSearchParam *) param, GTK_JUSTIFY_CENTER);
+    gnc_search_param_set_passive ((GNCSearchParam *) param, FALSE);
+    gnc_search_param_set_non_resizeable ((GNCSearchParam *) param, TRUE);
+    columns = g_list_prepend (columns, param);
+
     columns = gnc_search_param_prepend_with_justify (columns, _("Amount"),
               GTK_JUSTIFY_RIGHT,
               NULL, GNC_ID_SPLIT,
@@ -407,15 +447,6 @@ gnc_reconcile_view_init (GNCReconcileView *view)
     columns = gnc_search_param_prepend (columns, _("Date"), NULL, GNC_ID_SPLIT,
                                         SPLIT_TRANS, TRANS_DATE_POSTED, NULL);
 
-    param = gnc_search_param_simple_new();
-    gnc_search_param_set_param_fcn (param, QOF_TYPE_BOOLEAN,
-                                    gnc_reconcile_view_is_reconciled, view);
-    gnc_search_param_set_title ((GNCSearchParam *) param, _("Reconciled:R") + 11);
-    gnc_search_param_set_justify ((GNCSearchParam *) param, GTK_JUSTIFY_CENTER);
-    gnc_search_param_set_passive ((GNCSearchParam *) param, FALSE);
-    gnc_search_param_set_non_resizeable ((GNCSearchParam *) param, TRUE);
-    columns = g_list_prepend (columns, param);
-
     view->column_list = columns;
 }
 
@@ -470,25 +501,59 @@ gnc_reconcile_view_class_init (GNCReconcileViewClass *klass)
 }
 
 
-static void
+static gboolean
 gnc_reconcile_view_toggle_split (GNCReconcileView *view, Split *split)
 {
     Split *current;
 
+    g_return_val_if_fail (GNC_IS_RECONCILE_VIEW (view), FALSE);
+    g_return_val_if_fail (view->reconciled != NULL, FALSE);
+
+    current = g_hash_table_lookup (view->reconciled, split);
+
+    if (current == NULL)
+    {
+        g_hash_table_insert (view->reconciled, split, split);
+        return TRUE;
+    }
+    else
+    {
+        g_hash_table_remove (view->reconciled, split);
+        return FALSE;
+    }
+}
+
+
+/** Insert or remove a split from the list of splits to be reconciled
+ *   (view->reconciled) so that all other splits in the same transaction
+ *   for the account being reconciled (including children), are the same
+ *   reconciliation state as the split that has been toggled.
+ *
+ *  @param view The view to use.
+ *
+ *  @param split The split to be inserted or removed
+ *
+ *  @param reconcile TRUE=insert, FALSE=remove
+ */
+static void
+gnc_reconcile_view_rec_or_unrec_split (GNCReconcileView *view, Split *split, gboolean reconcile)
+{
+    Split *current;
+
     g_return_if_fail (GNC_IS_RECONCILE_VIEW (view));
     g_return_if_fail (view->reconciled != NULL);
 
     current = g_hash_table_lookup (view->reconciled, split);
 
-    if (current == NULL)
+    if (current == NULL && reconcile)
         g_hash_table_insert (view->reconciled, split, split);
-    else
+    if ((current != NULL) && (!reconcile))
         g_hash_table_remove (view->reconciled, split);
 }
 
 
 static void
-gnc_reconcile_view_toggle_children (Account *account, GNCReconcileView *view, Split *split)
+gnc_reconcile_view_toggle_children (Account *account, GNCReconcileView *view, Split *split, gboolean reconcile)
 {
     GList       *child_accounts, *node;
     Transaction *transaction;
@@ -498,7 +563,8 @@ gnc_reconcile_view_toggle_children (Account *account, GNCReconcileView *view, Sp
      * in the same hierarchy as the account being reconciled (not necessarily
      * the account this split is from.)
      *
-     * For each of these splits toggle them all to the same state.
+     * For each of these splits set them to the same state as the split whose
+     * checkbox was toggled.
      */
     child_accounts = gnc_account_get_descendants (account);
     child_accounts = g_list_prepend (child_accounts, account);
@@ -547,7 +613,8 @@ gnc_reconcile_view_toggle_children (Account *account, GNCReconcileView *view, Sp
             {
                 gboolean toggled;
                 gtk_tree_model_get (model, &iter, REC_RECN, &toggled, -1);
-                gtk_list_store_set (GTK_LIST_STORE (model), &iter, REC_RECN, !toggled, -1);
+                if (toggled != reconcile)
+                    gtk_list_store_set (GTK_LIST_STORE (model), &iter, REC_RECN, reconcile, -1);
                 break;
             }
 
@@ -555,7 +622,7 @@ gnc_reconcile_view_toggle_children (Account *account, GNCReconcileView *view, Sp
         }
 
         /* ...and toggle its reconciled state in the internal hash */
-        gnc_reconcile_view_toggle_split (current_view, other_split);
+        gnc_reconcile_view_rec_or_unrec_split (current_view, other_split, reconcile);
     }
     g_list_free (child_accounts);
 }
@@ -565,15 +632,16 @@ static void
 gnc_reconcile_view_toggle (GNCReconcileView *view, Split *split)
 {
     gboolean include_children;
+    gboolean is_reconciled;
 
     g_return_if_fail (GNC_IS_RECONCILE_VIEW (view));
     g_return_if_fail (view->reconciled != NULL);
 
-    gnc_reconcile_view_toggle_split (view, split);
+    is_reconciled = gnc_reconcile_view_toggle_split (view, split);
 
     include_children = xaccAccountGetReconcileChildrenStatus (view->account);
     if (include_children)
-        gnc_reconcile_view_toggle_children (view->account, view, split);
+        gnc_reconcile_view_toggle_children (view->account, view, split, is_reconciled);
 
     g_signal_emit (G_OBJECT (view),
                    reconcile_view_signals[TOGGLE_RECONCILED], 0, split);
