@@ -103,7 +103,7 @@ check_readonly_threshold (const gchar *datestr, GDate *d, gboolean warn)
             gchar *dialog_msg = _("The entered date of the transaction is "
                           "older than the \"Read-Only Threshold\" set for "
                           "this book. This setting can be changed in "
-                          "File -> Properties -> Accounts, resetting to the threshold.");
+                          "File->Properties->Accounts, resetting to the threshold.");
             gchar *dialog_title = _("Cannot store a transaction at this date");
             GtkWidget *dialog = gtk_message_dialog_new(gnc_ui_get_main_window (NULL),
                                    0,
@@ -710,34 +710,18 @@ gnc_date_cell_leave (BasicCell *bcell)
     box->calendar_popped = FALSE;
 
     /* Refresh the date to expand any shortcuts. */
-    gnc_date_cell_get_date ((DateCell *)bcell, &time);
+    gnc_date_cell_get_date ((DateCell *)bcell, &time, TRUE);
     gnc_date_cell_set_value_secs ((DateCell *)bcell, time);
 }
 
 void
-gnc_date_cell_get_date_gdate (DateCell *cell, GDate *date)
-{
-    PopBox *box = cell->cell.gui_private;
-
-    if (!cell || !date)
-        return;
-
-    gnc_parse_date (&(box->date), cell->cell.value, FALSE);
-
-    g_date_set_dmy(date,
-                   box->date.tm_mday,
-                   box->date.tm_mon + 1,
-                   box->date.tm_year + 1900);
-}
-
-void
-gnc_date_cell_get_date (DateCell *cell, time64 *time)
+gnc_date_cell_get_date (DateCell *cell, time64 *time, gboolean warn)
 {
     PopBox *box = cell->cell.gui_private;
     if (!cell || !time)
         return;
 
-    gnc_parse_date (&(box->date), cell->cell.value, TRUE);
+    gnc_parse_date (&(box->date), cell->cell.value, warn);
     *time = gnc_mktime (&box->date);
 }
 
